@@ -877,7 +877,7 @@ return TRUE;}
 		}
 		case GDK_KEY_asciicircum: {
 			bool input_xor = (caret_as_xor != ((state & GDK_CONTROL_MASK) > 0));
-			if(rpn_mode && rpn_keys) {
+			if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 				calculateRPN(input_xor ? OPERATION_BITWISE_XOR : OPERATION_RAISE);
 				return TRUE;
 			}
@@ -911,7 +911,7 @@ return TRUE;}
 				overwrite_expression_selection("/");
 				return TRUE;
 			}
-			if(rpn_mode && rpn_keys) {
+			if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 				calculateRPN(OPERATION_DIVIDE);
 				return TRUE;
 			}
@@ -925,7 +925,7 @@ return TRUE;}
 		}
 		case GDK_KEY_plus: {}
 		case GDK_KEY_KP_Add: {
-			if(rpn_mode && rpn_keys) {
+			if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 				calculateRPN(OPERATION_ADD);
 				return TRUE;
 			}
@@ -943,7 +943,7 @@ return TRUE;}
 				insert_button_function(CALCULATOR->getActiveFunction("neg"));
 				return TRUE;
 			}
-			if(rpn_mode && rpn_keys) {
+			if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 				if(!expression_is_empty()) {
 					GtkTextIter icur;
 					if(gtk_text_buffer_get_has_selection(expression_edit_buffer())) {
@@ -971,7 +971,7 @@ return TRUE;}
 		case GDK_KEY_KP_Multiply: {}
 		case GDK_KEY_asterisk: {
 			if(state & GDK_CONTROL_MASK) {
-				if(rpn_mode && rpn_keys) {
+				if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 					calculateRPN(OPERATION_RAISE);
 					return TRUE;
 				}
@@ -982,7 +982,7 @@ return TRUE;}
 				overwrite_expression_selection("^");
 				return TRUE;
 			}
-			if(rpn_mode && rpn_keys) {
+			if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 				calculateRPN(OPERATION_MULTIPLY);
 				return TRUE;
 			}
@@ -996,7 +996,7 @@ return TRUE;}
 		}
 		case GDK_KEY_E: {
 			if(state & GDK_CONTROL_MASK) {
-				if(rpn_mode && rpn_keys) {
+				if(rpn_mode && rpn_keys && evalops.parse_options.parsing_mode != PARSING_MODE_RPN) {
 					calculateRPN(OPERATION_EXP10);
 					return TRUE;
 				}
@@ -1722,8 +1722,10 @@ void create_expression_edit() {
 #else
 	gtk_text_view_set_left_margin(GTK_TEXT_VIEW(expression_edit_widget()), 12);
 	gtk_text_view_set_right_margin(GTK_TEXT_VIEW(expression_edit_widget()), 6);
-	gtk_text_view_set_border_window_size(GTK_TEXT_VIEW(expression_edit_widget()), GTK_TEXT_WINDOW_TOP, 6);
-	gtk_text_view_set_border_window_size(GTK_TEXT_VIEW(expression_edit_widget()), GTK_TEXT_WINDOW_BOTTOM, 6);
+	if(RUNTIME_CHECK_GTK_VERSION_LESS(3, 22)) {
+		gtk_text_view_set_border_window_size(GTK_TEXT_VIEW(expression_edit_widget()), GTK_TEXT_WINDOW_TOP, 6);
+		gtk_text_view_set_border_window_size(GTK_TEXT_VIEW(expression_edit_widget()), GTK_TEXT_WINDOW_BOTTOM, 6);
+	}
 #endif
 
 #if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION > 22 || (GTK_MINOR_VERSION == 22 && GTK_MICRO_VERSION >= 20)
@@ -1766,6 +1768,7 @@ void create_expression_edit() {
 	gtk_style_context_add_provider(gtk_widget_get_style_context(expression_edit_widget()), GTK_STYLE_PROVIDER(expressionborder_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	string border_css = topframe_css; border_css += "}";
 	gsub("*", "textview.view > border", border_css);
+	if(RUNTIME_CHECK_GTK_VERSION(3, 22)) border_css += "\ntextview.view {padding-top: 6px; padding-bottom: 6px;}";
 	gtk_css_provider_load_from_data(expressionborder_provider, border_css.c_str(), -1, NULL);
 #endif
 	GtkCssProvider *expression_provider2 = gtk_css_provider_new();
