@@ -428,9 +428,9 @@ void on_tFunctions_selection_changed(GtkTreeSelection *treeselection, gpointer)
 			gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(functions_builder, "functions_button_edit")), !f->isBuiltin());
 			gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(functions_builder, "functions_button_deactivate")), TRUE);
 			if(f->isActive()) {
-				gtk_label_set_text_with_mnemonic(GTK_LABEL(gtk_builder_get_object(functions_builder, "functions_buttonlabel_deactivate")), _("Deacti_vate"));
+				gtk_label_set_text_with_mnemonic(GTK_LABEL(gtk_builder_get_object(functions_builder, "functions_buttonlabel_deactivate")), _("Deac_tivate"));
 			} else {
-				gtk_label_set_text_with_mnemonic(GTK_LABEL(gtk_builder_get_object(functions_builder, "functions_buttonlabel_deactivate")), _("Acti_vate"));
+				gtk_label_set_text_with_mnemonic(GTK_LABEL(gtk_builder_get_object(functions_builder, "functions_buttonlabel_deactivate")), _("Ac_tivate"));
 			}
 			gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(functions_builder, "functions_button_insert")), f->isActive());
 			gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(functions_builder, "functions_button_apply")), f->isActive() && ((f->minargs() <= 1 && f != CALCULATOR->f_logn) || rpn_mode));
@@ -479,20 +479,18 @@ void on_functions_button_delete_clicked(GtkButton*, gpointer) {
 	GtkTreeIter iter;
 	MathFunction *f = get_selected_function();
 	if(!f || !f->isLocal()) return;
-	//ensure removal of all references in Calculator
-	f->destroy();
 	//update menus and trees
 	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(tFunctions)), &model, &iter)) {
 		//reselected selected function category
 		GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
 		string str = selected_function_category;
-		function_removed(f);
+		remove_function(f);
 		if(str == selected_function_category) {
 			gtk_tree_selection_select_path(gtk_tree_view_get_selection(GTK_TREE_VIEW(tFunctions)), path);
 		}
 		gtk_tree_path_free(path);
 	} else {
-		function_removed(f);
+		remove_function(f);
 	}
 }
 
