@@ -164,7 +164,7 @@ void insert_function_do(MathFunction *f, FunctionDialog *fd) {
 	string str = f->preferredInputName(printops.abbreviate_names, printops.use_unicode_signs, false, false, &can_display_unicode_string_function, (void*) expression_edit_widget()).formattedName(TYPE_FUNCTION, true) + "(", str2;
 
 	int argcount = fd->args;
-	if(f->maxargs() > 0 && f->minargs() < f->maxargs() && argcount > f->minargs()) {
+	if((f->maxargs() < 0 || f->minargs() < f->maxargs()) && argcount > f->minargs()) {
 		while(true) {
 			string defstr = localize_expression(f->getDefaultValue(argcount));
 			remove_blank_ends(defstr);
@@ -257,6 +257,7 @@ void insert_function_do(MathFunction *f, FunctionDialog *fd) {
 		str += str2;
 	}
 	str += ")";
+	restore_expression_selection();
 	insert_text(str.c_str());
 	if(fd->add_to_menu) function_inserted(f);
 }
@@ -386,8 +387,7 @@ void insert_function(MathFunction *f, GtkWindow *parent, bool add_to_menu) {
 		return;
 	}
 
-	GtkTextIter istart, iend;
-	gtk_text_buffer_get_selection_bounds(expression_edit_buffer(), &istart, &iend);
+	store_expression_selection();
 
 	if(function_dialogs.find(f) != function_dialogs.end()) {
 		FunctionDialog *fd = function_dialogs[f];
@@ -424,7 +424,7 @@ void insert_function(MathFunction *f, GtkWindow *parent, bool add_to_menu) {
 	} else if(f->minargs() > 0) {
 		args = f->minargs();
 		while(!f->getDefaultValue(args + 1).empty()) args++;
-		args++;
+		if(args == 1 || f->id() == FUNCTION_ID_PLOT) args++;
 	} else {
 		args = 1;
 		has_vector = true;
@@ -842,10 +842,6 @@ void insert_function(MathFunction *f, GtkWindow *parent, bool add_to_menu) {
 
 	gtk_widget_show_all(fd->dialog);
 
-	block_undo();
-	gtk_text_buffer_select_range(expression_edit_buffer(), &istart, &iend);
-	unblock_undo();
-
 }
 
 bool is_number(const gchar *expr) {
